// Copyright (c) Microsoft Corporation
// Licensed under the MIT license.
/**
 * Creates a new OnceQueue with the given initial values.
 */
export function createOnceQueue(...initialValues) {
    const visited = new Set();
    const queue = [];
    let idx = 0;
    const oncequeue = {
        add(value) {
            if (!visited.has(value)) {
                visited.add(value);
                queue.push(value);
            }
        },
        take() {
            if (idx < queue.length) {
                return queue[idx++];
            }
            else {
                return undefined;
            }
        },
        isEmpty() {
            return idx >= queue.length;
        },
    };
    for (const value of initialValues) {
        oncequeue.add(value);
    }
    return oncequeue;
}
//# sourceMappingURL=once-queue.js.map